@@ -1,11 +1,9 @@
-"drmc" <- 
-function(constr = FALSE, errorm = TRUE, maxDose = 1e-1, maxIt = 500, method = "BFGS", 
-noMessage = FALSE, relTol = 1e-7, rmNA = FALSE, useD = FALSE, trace = FALSE, warnVal = -1, zeroTol = 0)
+"drmc" <- function(constr = FALSE, errorm = TRUE, maxIt = 500, method = "BFGS", 
+noMessage = FALSE, relTol = 1e-7, rmNA = FALSE, useD = FALSE, trace = FALSE, warnVal = -1)
 {
     return(list(
                 constr = constr,
                 errorm = errorm,
-                maxDose = maxDose,
                 maxIt = maxIt, 
                 method = method,
                 noMessage = noMessage,
@@ -13,6 +11,5 @@ noMessage = FALSE, relTol = 1e-7, rmNA = FALSE, useD = FALSE, trace = FALSE, war
                 rmNA = rmNA, 
                 useD = useD,
                 trace = trace,
-                warnVal = warnVal, 
-                zeroTol = zeroTol))
+                warnVal = warnVal))
 }
